@@ -1,6 +1,6 @@
 package Net::IPAM::Block;
 
-our $VERSION = '4.10';
+our $VERSION = '4.11';
 
 use 5.10.0;
 use strict;
@@ -657,7 +657,7 @@ sub diff {
   }
 
   # last diff
-  if ( $cursor->cmp( $outer->last ) <= 0 ) {
+  if ( defined $cursor && $cursor->cmp( $outer->last ) <= 0 ) {
     my $base_ip = $cursor;
     my $last_ip = $outer->last;
 
